@@ -18,23 +18,22 @@ import json
 import uuid
 
 import fixtures
-import httpretty
 from mox3 import mox
+from oslo.serialization import jsonutils
 import requests
+import requests_mock
 import six
 import testtools
 
 from keystoneclient.auth.identity import v2 as ks_v2_auth
 from keystoneclient.auth.identity import v3 as ks_v3_auth
 from keystoneclient import exceptions as ks_exceptions
-from keystoneclient.fixture import v2 as ks_v2_fixture
-from keystoneclient.fixture import v3 as ks_v3_fixture
+from keystoneclient import fixture
 from keystoneclient import session
 
 from neutronclient import client
 from neutronclient.common import exceptions
 from neutronclient.common import utils
-from neutronclient.openstack.common import jsonutils
 
 
 USERNAME = 'testuser'
@@ -47,28 +46,14 @@ PUBLIC_ENDPOINT_URL = 'public_%s' % ENDPOINT_URL
 ADMIN_ENDPOINT_URL = 'admin_%s' % ENDPOINT_URL
 INTERNAL_ENDPOINT_URL = 'internal_%s' % ENDPOINT_URL
 ENDPOINT_OVERRIDE = 'otherurl'
-TOKEN = 'tokentoken'
 TOKENID = uuid.uuid4().hex
 REGION = 'RegionOne'
 NOAUTH = 'noauth'
 
-KS_TOKEN_RESULT = {
-    'access': {
-        'token': {'id': TOKEN,
-                  'expires': '2012-08-11T07:49:01Z',
-                  'tenant': {'id': str(uuid.uuid1())}},
-        'user': {'id': str(uuid.uuid1())},
-        'serviceCatalog': [
-            {'endpoints_links': [],
-             'endpoints': [{'adminURL': ENDPOINT_URL,
-                            'internalURL': ENDPOINT_URL,
-                            'publicURL': ENDPOINT_URL,
-                            'region': REGION}],
-             'type': 'network',
-             'name': 'Neutron Service'}
-        ]
-    }
-}
+KS_TOKEN_RESULT = fixture.V2Token()
+KS_TOKEN_RESULT.set_scope()
+_s = KS_TOKEN_RESULT.add_service('network', 'Neutron Service')
+_s.add_endpoint(ENDPOINT_URL, region=REGION)
 
 ENDPOINTS_RESULT = {
     'endpoints': [{
@@ -81,54 +66,18 @@ ENDPOINTS_RESULT = {
     }]
 }
 
-BASE_HOST = 'http://keystone.example.com'
-BASE_URL = "%s:5000/" % BASE_HOST
-UPDATED = '2013-03-06T00:00:00Z'
+BASE_URL = "http://keystone.example.com:5000/"
 
-# FIXME (bklei): A future release of keystoneclient will support
-# a discovery fixture which can replace these constants and clean
-# this up.
 V2_URL = "%sv2.0" % BASE_URL
-V2_DESCRIBED_BY_HTML = {'href': 'http://docs.openstack.org/api/'
-                                'openstack-identity-service/2.0/content/',
-                        'rel': 'describedby',
-                        'type': 'text/html'}
-
-V2_DESCRIBED_BY_PDF = {'href': 'http://docs.openstack.org/api/openstack-ident'
-                               'ity-service/2.0/identity-dev-guide-2.0.pdf',
-                       'rel': 'describedby',
-                       'type': 'application/pdf'}
-
-V2_VERSION = {'id': 'v2.0',
-              'links': [{'href': V2_URL, 'rel': 'self'},
-                        V2_DESCRIBED_BY_HTML, V2_DESCRIBED_BY_PDF],
-              'status': 'stable',
-              'updated': UPDATED}
-
 V3_URL = "%sv3" % BASE_URL
-V3_MEDIA_TYPES = [{'base': 'application/json',
-                   'type': 'application/vnd.openstack.identity-v3+json'},
-                  {'base': 'application/xml',
-                   'type': 'application/vnd.openstack.identity-v3+xml'}]
 
-V3_VERSION = {'id': 'v3.0',
-              'links': [{'href': V3_URL, 'rel': 'self'}],
-              'media-types': V3_MEDIA_TYPES,
-              'status': 'stable',
-              'updated': UPDATED}
+_v2 = fixture.V2Discovery(V2_URL)
+_v3 = fixture.V3Discovery(V3_URL)
 
+V3_VERSION_LIST = jsonutils.dumps({'versions': {'values': [_v2, _v3]}})
 
-def _create_version_entry(version):
-    return jsonutils.dumps({'version': version})
-
-
-def _create_version_list(versions):
-    return jsonutils.dumps({'versions': {'values': versions}})
-
-
-V3_VERSION_LIST = _create_version_list([V3_VERSION, V2_VERSION])
-V3_VERSION_ENTRY = _create_version_entry(V3_VERSION)
-V2_VERSION_ENTRY = _create_version_entry(V2_VERSION)
+V2_VERSION_ENTRY = {'version': _v2}
+V3_VERSION_ENTRY = {'version': _v3}
 
 
 def get_response(status_code, headers=None):
@@ -138,36 +87,36 @@ def get_response(status_code, headers=None):
     return response
 
 
-def setup_keystone_v2():
-    v2_token = ks_v2_fixture.Token(token_id=TOKENID)
+def setup_keystone_v2(mrequests):
+    v2_token = fixture.V2Token(token_id=TOKENID)
     service = v2_token.add_service('network')
     service.add_endpoint(PUBLIC_ENDPOINT_URL, region=REGION)
 
-    httpretty.register_uri(httpretty.POST,
+    mrequests.register_uri('POST',
                            '%s/tokens' % (V2_URL),
-                           body=json.dumps(v2_token))
+                           json=v2_token)
 
     auth_session = session.Session()
     auth_plugin = ks_v2_auth.Password(V2_URL, 'xx', 'xx')
     return auth_session, auth_plugin
 
 
-def setup_keystone_v3():
-    httpretty.register_uri(httpretty.GET,
+def setup_keystone_v3(mrequests):
+    mrequests.register_uri('GET',
                            V3_URL,
-                           body=V3_VERSION_ENTRY)
+                           json=V3_VERSION_ENTRY)
 
-    v3_token = ks_v3_fixture.Token()
+    v3_token = fixture.V3Token()
     service = v3_token.add_service('network')
     service.add_standard_endpoints(public=PUBLIC_ENDPOINT_URL,
                                    admin=ADMIN_ENDPOINT_URL,
                                    internal=INTERNAL_ENDPOINT_URL,
                                    region=REGION)
 
-    httpretty.register_uri(httpretty.POST,
+    mrequests.register_uri('POST',
                            '%s/auth/tokens' % (V3_URL),
-                           body=json.dumps(v3_token),
-                           adding_headers={'X-Subject-Token': TOKENID})
+                           text=json.dumps(v3_token),
+                           headers={'X-Subject-Token': TOKENID})
 
     auth_session = session.Session()
     auth_plugin = ks_v3_auth.Password(V3_URL,
@@ -235,21 +184,22 @@ class CLITestAuthKeystone(testtools.TestCase):
         """Test that Client.get_auth_info() works even if client was
            instantiated with predefined token.
         """
+        token_id = uuid.uuid4().hex
         client_ = client.HTTPClient(username=USERNAME,
                                     tenant_name=TENANT_NAME,
-                                    token=TOKEN,
+                                    token=token_id,
                                     password=PASSWORD,
                                     auth_url=AUTH_URL,
                                     region_name=REGION)
-        expected = {'auth_token': TOKEN,
+        expected = {'auth_token': token_id,
                     'auth_tenant_id': None,
                     'auth_user_id': None,
                     'endpoint_url': self.client.endpoint_url}
         self.assertEqual(client_.get_auth_info(), expected)
 
-    @httpretty.activate
-    def test_get_token(self):
-        auth_session, auth_plugin = setup_keystone_v2()
+    @requests_mock.Mocker()
+    def test_get_token(self, mrequests):
+        auth_session, auth_plugin = setup_keystone_v2(mrequests)
 
         self.client = client.construct_http_client(
             username=USERNAME,
@@ -275,7 +225,8 @@ class CLITestAuthKeystone(testtools.TestCase):
     def test_refresh_token(self):
         self.mox.StubOutWithMock(self.client, "request")
 
-        self.client.auth_token = TOKEN
+        token_id = uuid.uuid4().hex
+        self.client.auth_token = token_id
         self.client.endpoint_url = ENDPOINT_URL
 
         res200 = get_response(200)
@@ -284,7 +235,7 @@ class CLITestAuthKeystone(testtools.TestCase):
         # If a token is expired, neutron server retruns 401
         self.client.request(
             mox.StrContains(ENDPOINT_URL + '/resource'), 'GET',
-            headers=mox.ContainsKeyValue('X-Auth-Token', TOKEN)
+            headers=mox.ContainsKeyValue('X-Auth-Token', token_id)
         ).AndReturn((res401, ''))
         self.client.request(
             AUTH_URL + '/tokens', 'POST',
@@ -292,7 +243,8 @@ class CLITestAuthKeystone(testtools.TestCase):
         ).AndReturn((res200, json.dumps(KS_TOKEN_RESULT)))
         self.client.request(
             mox.StrContains(ENDPOINT_URL + '/resource'), 'GET',
-            headers=mox.ContainsKeyValue('X-Auth-Token', TOKEN)
+            headers=mox.ContainsKeyValue('X-Auth-Token',
+                                         KS_TOKEN_RESULT.token_id)
         ).AndReturn((res200, ''))
         self.mox.ReplayAll()
         self.client.do_request('/resource', 'GET')
@@ -301,7 +253,8 @@ class CLITestAuthKeystone(testtools.TestCase):
         self.mox.StubOutWithMock(self.client, "request")
         self.client.auth_url = None
 
-        self.client.auth_token = TOKEN
+        token_id = uuid.uuid4().hex
+        self.client.auth_token = token_id
         self.client.endpoint_url = ENDPOINT_URL
 
         res401 = get_response(401)
@@ -309,7 +262,7 @@ class CLITestAuthKeystone(testtools.TestCase):
         # If a token is expired, neutron server returns 401
         self.client.request(
             mox.StrContains(ENDPOINT_URL + '/resource'), 'GET',
-            headers=mox.ContainsKeyValue('X-Auth-Token', TOKEN)
+            headers=mox.ContainsKeyValue('X-Auth-Token', token_id)
         ).AndReturn((res401, ''))
         self.mox.ReplayAll()
         self.assertRaises(exceptions.NoAuthURLProvided,
@@ -326,17 +279,18 @@ class CLITestAuthKeystone(testtools.TestCase):
     def test_get_endpoint_url(self):
         self.mox.StubOutWithMock(self.client, "request")
 
-        self.client.auth_token = TOKEN
+        token_id = uuid.uuid4().hex
+        self.client.auth_token = token_id
 
         res200 = get_response(200)
 
         self.client.request(
-            mox.StrContains(AUTH_URL + '/tokens/%s/endpoints' % TOKEN), 'GET',
-            headers=mox.IsA(dict)
+            mox.StrContains(AUTH_URL + '/tokens/%s/endpoints' % token_id),
+            'GET', headers=mox.IsA(dict)
         ).AndReturn((res200, json.dumps(ENDPOINTS_RESULT)))
         self.client.request(
             mox.StrContains(ENDPOINT_URL + '/resource'), 'GET',
-            headers=mox.ContainsKeyValue('X-Auth-Token', TOKEN)
+            headers=mox.ContainsKeyValue('X-Auth-Token', token_id)
         ).AndReturn((res200, ''))
         self.mox.ReplayAll()
         self.client.do_request('/resource', 'GET')
@@ -350,12 +304,14 @@ class CLITestAuthKeystone(testtools.TestCase):
 
         self.mox.StubOutWithMock(self.client, "request")
 
-        self.client.auth_token = TOKEN
+        token_id = uuid.uuid4().hex
+
+        self.client.auth_token = token_id
         res200 = get_response(200)
 
         self.client.request(
             mox.StrContains(ENDPOINT_OVERRIDE + '/resource'), 'GET',
-            headers=mox.ContainsKeyValue('X-Auth-Token', TOKEN)
+            headers=mox.ContainsKeyValue('X-Auth-Token', token_id)
         ).AndReturn((res200, ''))
         self.mox.ReplayAll()
         self.client.do_request('/resource', 'GET')
@@ -367,12 +323,13 @@ class CLITestAuthKeystone(testtools.TestCase):
             auth_url=AUTH_URL, region_name=REGION, endpoint_type='otherURL')
         self.mox.StubOutWithMock(self.client, "request")
 
-        self.client.auth_token = TOKEN
+        token_id = uuid.uuid4().hex
+        self.client.auth_token = token_id
         res200 = get_response(200)
 
         self.client.request(
-            mox.StrContains(AUTH_URL + '/tokens/%s/endpoints' % TOKEN), 'GET',
-            headers=mox.IsA(dict)
+            mox.StrContains(AUTH_URL + '/tokens/%s/endpoints' % token_id),
+            'GET', headers=mox.IsA(dict)
         ).AndReturn((res200, json.dumps(ENDPOINTS_RESULT)))
         self.mox.ReplayAll()
         self.assertRaises(exceptions.EndpointTypeNotFound,
@@ -383,14 +340,15 @@ class CLITestAuthKeystone(testtools.TestCase):
     def test_get_endpoint_url_failed(self):
         self.mox.StubOutWithMock(self.client, "request")
 
-        self.client.auth_token = TOKEN
+        token_id = uuid.uuid4().hex
+        self.client.auth_token = token_id
 
         res200 = get_response(200)
         res401 = get_response(401)
 
         self.client.request(
-            mox.StrContains(AUTH_URL + '/tokens/%s/endpoints' % TOKEN), 'GET',
-            headers=mox.IsA(dict)
+            mox.StrContains(AUTH_URL + '/tokens/%s/endpoints' % token_id),
+            'GET', headers=mox.IsA(dict)
         ).AndReturn((res401, ''))
         self.client.request(
             AUTH_URL + '/tokens', 'POST',
@@ -398,14 +356,15 @@ class CLITestAuthKeystone(testtools.TestCase):
         ).AndReturn((res200, json.dumps(KS_TOKEN_RESULT)))
         self.client.request(
             mox.StrContains(ENDPOINT_URL + '/resource'), 'GET',
-            headers=mox.ContainsKeyValue('X-Auth-Token', TOKEN)
+            headers=mox.ContainsKeyValue('X-Auth-Token',
+                                         KS_TOKEN_RESULT.token_id)
         ).AndReturn((res200, ''))
         self.mox.ReplayAll()
         self.client.do_request('/resource', 'GET')
 
-    @httpretty.activate
-    def test_endpoint_type(self):
-        auth_session, auth_plugin = setup_keystone_v3()
+    @requests_mock.Mocker()
+    def test_endpoint_type(self, mrequests):
+        auth_session, auth_plugin = setup_keystone_v3(mrequests)
 
         # Test default behavior is to choose public.
         self.client = client.construct_http_client(
@@ -518,9 +477,9 @@ class TestKeystoneClientVersions(testtools.TestCase):
         self.addCleanup(self.mox.VerifyAll)
         self.addCleanup(self.mox.UnsetStubs)
 
-    @httpretty.activate
-    def test_v2_auth(self):
-        auth_session, auth_plugin = setup_keystone_v2()
+    @requests_mock.Mocker()
+    def test_v2_auth(self, mrequests):
+        auth_session, auth_plugin = setup_keystone_v2(mrequests)
         res200 = get_response(200)
 
         self.client = client.construct_http_client(
@@ -542,9 +501,9 @@ class TestKeystoneClientVersions(testtools.TestCase):
         self.mox.ReplayAll()
         self.client.do_request('/resource', 'GET')
 
-    @httpretty.activate
-    def test_v3_auth(self):
-        auth_session, auth_plugin = setup_keystone_v3()
+    @requests_mock.Mocker()
+    def test_v3_auth(self, mrequests):
+        auth_session, auth_plugin = setup_keystone_v3(mrequests)
         res200 = get_response(200)
 
         self.client = client.construct_http_client(
